@@ -64,3 +64,6 @@
 #include <ell/gpio.h>
 #include <ell/path.h>
 #include <ell/acd.h>
+#include <ell/tester.h>
+#include <ell/netconfig.h>
+#include <ell/sysctl.h>
