@@ -25,6 +25,9 @@
 #endif
 
 #include <assert.h>
+#include <limits.h>
+#include <stdio.h>
+#include <errno.h>
 
 #include <ell/ell.h>
 
@@ -39,6 +42,24 @@ static void test_hexstring(const void *test_data)
 	l_free(hex);
 }
 
+static void test_hexstringv(const void *test_data)
+{
+	unsigned char test1[] = { 0x74, 0x65, 0x73, 0x74, 0x00 };
+	unsigned char test2[] = { 0x74, 0x65, 0x73 };
+	struct iovec iov[2];
+	char *hex;
+
+	iov[0].iov_base = test1;
+	iov[0].iov_len = 5;
+	iov[1].iov_base = test2;
+	iov[1].iov_len = 3;
+
+	hex = l_util_hexstringv(iov, 2);
+	assert(hex);
+	assert(!strcmp(hex, "7465737400746573"));
+	l_free(hex);
+}
+
 static void test_hexstring_upper(const void *test_data)
 {
 	unsigned char test[] = { 0x0a, 0x0b, 0x0c, 0xde, 0xf2 };
@@ -145,12 +166,57 @@ static void test_in_set(const void *test_data)
 	assert(!L_IN_STRSET("a"));
 }
 
+static void test_safe_atoux(const void *test_data)
+{
+	uint32_t r;
+	uint16_t h;
+	uint8_t c;
+	char s[64];
+
+	assert(!l_safe_atou32("234233", &r) && r == 234233);
+	assert(!l_safe_atou32("0", &r) && r == 0);
+
+	assert(!l_safe_atox32("a34", &r) && r == 0xa34);
+	assert(!l_safe_atox32("0xa34", &r) && r == 0xa34);
+	assert(l_safe_atou32("a34", NULL) == -EINVAL);
+
+	sprintf(s, "%u", UINT_MAX);
+	assert(!l_safe_atou32(s, &r) && r == UINT_MAX);
+
+	sprintf(s, "%x", UINT_MAX);
+	assert(!l_safe_atox32(s, &r) && r == UINT_MAX);
+
+	assert(l_safe_atou32("", NULL) == -EINVAL);
+	assert(l_safe_atox32("", NULL) == -EINVAL);
+
+	sprintf(s, "%llu", ULLONG_MAX);
+	assert(l_safe_atou32(s, NULL) == -ERANGE);
+
+	sprintf(s, "%llx", ULLONG_MAX);
+	assert(l_safe_atox32(s, NULL) == -ERANGE);
+
+	assert(l_safe_atou32("    3", NULL) == -EINVAL);
+	assert(l_safe_atou32("+3434", NULL) == -EINVAL);
+	assert(l_safe_atou32("-3434", NULL) == -EINVAL);
+	assert(l_safe_atou32("00000", &r) == -EINVAL);
+	assert(!l_safe_atox32("0002", &r) && r == 0x2);
+	assert(!l_safe_atox32("0x02", &r) && r == 0x2);
+
+	assert(l_safe_atox32("+0x3434", NULL) == -EINVAL);
+	assert(l_safe_atox32("-0x3434", NULL) == -EINVAL);
+
+	assert(!l_safe_atox16("0xffff", &h) && h == 0xffff);
+	assert(!l_safe_atox8("0xff", &c) && c == 0xff);
+	assert(l_safe_atox8("0xffff", &c) == -ERANGE);
+}
+
 int main(int argc, char *argv[])
 {
 	l_test_init(&argc, &argv);
 
 	l_test_add("l_util_hexstring", test_hexstring, NULL);
 	l_test_add("l_util_hexstring_upper", test_hexstring_upper, NULL);
+	l_test_add("l_util_hexstringv", test_hexstringv, NULL);
 	l_test_add("l_util_from_hexstring", test_from_hexstring, NULL);
 
 	l_test_add("l_util_has_suffix", test_has_suffix, NULL);
@@ -159,5 +225,7 @@ int main(int argc, char *argv[])
 
 	l_test_add("L_IN_SET", test_in_set, NULL);
 
+	l_test_add("l_safe_atoux", test_safe_atoux, NULL);
+
 	return l_test_run();
 }
